@@ -1,11 +1,12 @@
-
-from .terminal import Terminal
-from .box import Box
-from .waiting import Waiting
-from . import BoxStyles
-from .progressbar import ProgressBar
-
 from colorama import init as _colorama_init
+
+from . import BoxStyles
+from .box import Box
+from .cursor import Cursor
+from .progressbar import ProgressBar
+from .terminal import Terminal
+from .waiting import Waiting
+
 _colorama_init()
 
-__all__ = ['Terminal', 'Box', 'BoxStyles', 'Waiting', 'ProgressBar']
\ No newline at end of file
+__all__ = ['Terminal', 'Box', 'BoxStyles', 'Waiting', 'ProgressBar', 'Cursor']
