@@ -1,21 +1,22 @@
 # https://code.activestate.com/recipes/134892/
+import os
 
 class _Getch:
-    """Gets a single character from standard input.  Does not echo to the
-screen."""
+    """Gets a single character from standard input. Does not echo to the screen."""
+
     def __init__(self):
-        try:
+        if os.name == 'nt':
             self.impl = _GetchWindows()
-        except ImportError:
+        else:
             self.impl = _GetchUnix()
 
-    def __call__(self): return self.impl()
+    def __call__(self):
+        return self.impl()
 
 
 class _GetchUnix:
     def __init__(self):
-        import tty
-        import sys
+        pass
 
     def __call__(self):
         import sys
@@ -28,12 +29,12 @@ class _GetchUnix:
             ch = sys.stdin.read(1)
         finally:
             termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
-        return ch
+        return ch.encode('utf-8')
 
 
 class _GetchWindows:
     def __init__(self):
-        import msvcrt
+        pass
 
     def __call__(self):
         import msvcrt
